@@ -2,13 +2,13 @@ from __future__ import unicode_literals
 
 import logging
 
-from mopidy.backends import base, listener
+from mopidy import backend
 from mopidy.models import Playlist
 
-logger = logging.getLogger('mopidy.backends.gmusic')
+logger = logging.getLogger(__name__)
 
 
-class GMusicPlaylistsProvider(base.BasePlaylistsProvider):
+class GMusicPlaylistsProvider(backend.PlaylistsProvider):
 
     def create(self, name):
         pass  # TODO
@@ -24,7 +24,7 @@ class GMusicPlaylistsProvider(base.BasePlaylistsProvider):
     def refresh(self):
         playlists = []
 
-        for playlist in self.backend.session.get_all_playlist_contents():
+        for playlist in self.backend.session.get_all_user_playlist_contents():
             tracks = []
             for track in playlist['tracks']:
                 if not track['deleted']:
@@ -36,8 +36,21 @@ class GMusicPlaylistsProvider(base.BasePlaylistsProvider):
                                 tracks=tracks)
             playlists.append(playlist)
 
+        for playlist in self.backend.session.get_all_playlists():
+            if playlist.get('type') == 'SHARED':
+                tracks = []
+                tracklist = self.backend.session.get_shared_playlist_contents(
+                    playlist['shareToken'])
+                for track in tracklist:
+                        tracks += self.backend.library.lookup('gmusic:track:' +
+                                                              track['trackId'])
+                playlist = Playlist(uri='gmusic:playlist:' + playlist['id'],
+                                    name=playlist['name'],
+                                    tracks=tracks)
+                playlists.append(playlist)
+
         self.playlists = playlists
-        listener.BackendListener.send('playlists_loaded')
+        backend.BackendListener.send('playlists_loaded')
 
     def save(self, playlist):
         pass  # TODO
