@@ -4,7 +4,7 @@ import logging
 
 from gmusicapi import Mobileclient, Webclient, CallFailure
 
-logger = logging.getLogger('mopidy.backends.gmusic')
+logger = logging.getLogger(__name__)
 
 
 class GMusicSession(object):
@@ -48,12 +48,24 @@ class GMusicSession(object):
             except CallFailure as error:
                 logger.error(u'Failed to lookup "%s": %s', song_id, error)
 
-    def get_all_playlist_contents(self):
+    def get_all_user_playlist_contents(self):
         if self.api.is_authenticated():
             return self.api.get_all_user_playlist_contents()
         else:
             return {}
 
+    def get_shared_playlist_contents(self, shareToken):
+        if self.api.is_authenticated():
+            return self.api.get_shared_playlist_contents(shareToken)
+        else:
+            return {}
+
+    def get_all_playlists(self):
+        if self.api.is_authenticated():
+            return self.api.get_all_playlists()
+        else:
+            return {}
+
     def get_deviceid(self, username, password):
         logger.warning(u'No mobile device ID configured. '
                        u'Trying to detect one.')
